==> nextcloud-27.1.11.tgz: nextcloud/apps/user_status/l10n/nb.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nylige statuser",
    "No recent status changes" : "Ingen nylige statusendringer",
    "In a meeting" : "I et møte",
    "Commuting" : "Pendler",
    "Out sick" : "Syk",
    "Vacationing" : "På ferie",
    "Out of office" : "Fraværende",
    "Working remotely" : "Jobber utenfra",
    "In a call" : "I en samtale",
    "User status" : "Brukerstatus",
    "Clear status after" : "Fjern status etter",
    "Emoji for your status message" : "Emoji for statusmeldingene dine",
    "What is your status?" : "Hva er din status?",
    "Predefined statuses" : "Forhåndsdefinerte statuser",
    "Previously set" : "Tidligere angitt",
    "Reset status" : "Tilbakestill status",
    "Set status" : "Velg status",
    "Online status" : "Online-status",
    "Status message" : "Statusmelding",
    "Your status was set automatically" : "Statusen din ble satt",
    "Clear status message" : "Fjern statusmelding",
    "Set status message" : "Velg statusmelding",
    "Reset status to \"{icon} {message}\"" : "Tilbakestill status til \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Tilbakestill status til \"{message}\"",
    "Reset status to \"{icon}\"" : "Tilbakestill status til \"{icon}\"",
    "There was an error saving the status" : "Det oppsto en feil ved lagring av status",
    "There was an error clearing the status" : "Det oppsto en feil ved fjerning av status",
    "There was an error reverting the status" : "Det oppstod en feil under tilbakestilling av statusen",
    "Don't clear" : "Ikke fjern",
    "Today" : "I dag",
    "This week" : "Denne uken",
    "Online" : "Pålogget",
    "Away" : "Borte",
    "Do not disturb" : "Ikke forstyrr",
    "Invisible" : "Usynlig",
    "Offline" : "Frakoblet",
    "There was an error saving the new status" : "Det oppsto en feil ved lagring av ny status",
    "30 minutes" : "30 minutter",
    "1 hour" : "1 time",
    "4 hours" : "4 timer",
    "Mute all notifications" : "Demp alle varslinger",
    "Appear offline" : "Vis som frakoblet",
    "View profile" : "Vis profil"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/user_status/l10n/nb.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nylige statuser",
    "No recent status changes" : "Ingen nylige statusendringer",
    "In a meeting" : "I et møte",
    "Commuting" : "Pendler",
    "Out sick" : "Syk",
    "Vacationing" : "På ferie",
    "Out of office" : "Fraværende",
    "Working remotely" : "Jobber utenfra",
    "In a call" : "I en samtale",
    "User status" : "Brukerstatus",
    "Clear status after" : "Fjern status etter",
    "Emoji for your status message" : "Emoji for statusmeldingene dine",
    "What is your status?" : "Hva er din status?",
    "Predefined statuses" : "Forhåndsdefinerte statuser",
    "Previously set" : "Tidligere angitt",
    "Reset status" : "Tilbakestill status",
    "Set status" : "Velg status",
    "Online status" : "Online-status",
    "Status message" : "Statusmelding",
    "Your status was set automatically" : "Statusen din ble satt",
    "Clear status message" : "Fjern statusmelding",
    "Set status message" : "Velg statusmelding",
    "Reset status to \"{icon} {message}\"" : "Tilbakestill status til \"{icon} {message}\"",
    "Reset status to \"{message}\"" : "Tilbakestill status til \"{message}\"",
    "Reset status to \"{icon}\"" : "Tilbakestill status til \"{icon}\"",
    "There was an error saving the status" : "Det oppsto en feil ved lagring av status",
    "There was an error clearing the status" : "Det oppsto en feil ved fjerning av status",
    "There was an error reverting the status" : "Det oppstod en feil under tilbakestilling av statusen",
    "Don't clear" : "Ikke fjern",
    "Today" : "I dag",
    "This week" : "Denne uken",
    "Online" : "Pålogget",
    "Away" : "Borte",
    "Do not disturb" : "Ikke forstyrr",
    "Invisible" : "Usynlig",
    "Offline" : "Frakoblet",
    "There was an error saving the new status" : "Det oppsto en feil ved lagring av ny status",
    "30 minutes" : "30 minutter",
    "1 hour" : "1 time",
    "4 hours" : "4 timer",
    "Mute all notifications" : "Demp alle varslinger",
    "Appear offline" : "Vis som frakoblet",
    "View profile" : "Vis profil",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=2; plural=(n != 1);");
